abacusai.model_monitor_summary_from_org — AbacusAI documentation

# abacusai.model_monitor_summary_from_org

## Classes

`AbstractApiClass` |
`ModelMonitorSummaryFromOrg` | A summary of model monitor given an organization

## Module Contents

class abacusai.model_monitor_summary_from_org.AbstractApiClass(client, id)
  __eq__(other)

    Return self==value.

  _get_attribute_as_dict(attribute)

class abacusai.model_monitor_summary_from_org.ModelMonitorSummaryFromOrg(client, data=None, infos=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  A summary of model monitor given an organization

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - data (list) – A list of either model accuracy, drift, data integrity, or bias chart objects and their monitor version information.

    - infos (dict) – A dictionary of model monitor information.

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict